@@ -28,6 +28,7 @@ class TypeHintAdapter(abc.ABC):
   @abc.abstractmethod
   def _adapt_type_hint_impl(self, type_hint: t.Any, recurse: 'TypeHintAdapter') -> BaseType: ...
 
+
 class DefaultTypeHintAdapter(TypeHintAdapter):
   """
   Adapter for all the supported standard #typing type hints.
@@ -82,7 +83,7 @@ class DefaultTypeHintAdapter(TypeHintAdapter):
         return from_typing(type_)
 
     if isinstance(type_hint, type):
-      return ConcreteType(type_hint)
+      return from_typing(ConcreteType(type_hint))
 
     raise TypeHintAdapterError(self, f'unsupported type hint {type_hint!r}')
 
